# Flush AI

This is the python client SDK for Flush AI, a tool that allows you to generate images for free. You can generate imags using any Civit AI model, 
stable diffusion, and many other popular image generation models